==> codeforlife_portal-1.0.0.post0.dev311-py2.py3-none-any.whl: portal/middleware/ratelimit_login_attempts.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2016, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from django.core.urlresolvers import reverse_lazy
from django.http import HttpResponseRedirect
from ratelimit.decorators import ratelimit


def is_cms_toolbar_login_request(request):
    return request.method == 'POST' and 'cms-toolbar-login' in request.GET


class RateLimitLoginAttemptsMiddleware:

    @staticmethod
    @ratelimit('cms_login_ip', periods=['1m'], path=False, increment=lambda req, res: is_cms_toolbar_login_request(req))
    def process_request(request):
        limit = 5

        limits = getattr(request, 'limits', {'cms_login_ip': [0]})

        if limits['cms_login_ip'][0] > limit and is_cms_toolbar_login_request(request):
            return HttpResponseRedirect(reverse_lazy('locked_out'))
        return None

==> codeforlife_portal-1.2.1-py2.py3-none-any.whl: portal/middleware/ratelimit_login_attempts.py <==
# -*- coding: utf-8 -*-
# Code for Life
#
# Copyright (C) 2019, Ocado Innovation Limited
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# ADDITIONAL TERMS – Section 7 GNU General Public Licence
#
# This licence does not grant any right, title or interest in any “Ocado” logos,
# trade names or the trademark “Ocado” or any other trademarks or domain names
# owned by Ocado Innovation Limited or the Ocado group of companies or any other
# distinctive brand features of “Ocado” as may be secured from time to time. You
# must not distribute any modification of this program using the trademark
# “Ocado” or claim any affiliation or association with Ocado or its employees.
#
# You are not authorised to use the name Ocado (or any of its trade names) or
# the names of any author or contributor in advertising or for publicity purposes
# pertaining to the distribution of this program, without the prior written
# authorisation of Ocado.
#
# Any propagation, distribution or conveyance of this program must include this
# copyright notice and these terms. You must not misrepresent the origins of this
# program; modified versions of the program must be marked as such and not
# identified as the original program.
from django.core.urlresolvers import reverse_lazy
from django.http import HttpResponseRedirect
from ratelimit.decorators import ratelimit


def is_cms_toolbar_login_request(request):
    return request.method == "POST" and "cms-toolbar-login" in request.GET


class RateLimitLoginAttemptsMiddleware:
    @staticmethod
    @ratelimit(
        "cms_login_ip",
        periods=["1m"],
        path=False,
        increment=lambda req, res: is_cms_toolbar_login_request(req),
    )
    def process_request(request):
        limit = 5

        limits = getattr(request, "limits", {"cms_login_ip": [0]})

        if limits["cms_login_ip"][0] > limit and is_cms_toolbar_login_request(request):
            return HttpResponseRedirect(reverse_lazy("locked_out"))
        return None
